@@ -1,7 +1,7 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2013 UniPro <ugene@unipro.ru>
- * http://ugene.unipro.ru
+ * Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
+ * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,26 +22,31 @@
 #ifndef _U2_GT_RUNNABLES_FIND_REPEATS_DIALOG_FILLER_H_
 #define _U2_GT_RUNNABLES_FIND_REPEATS_DIALOG_FILLER_H_
 
-#include "GTUtilsDialog.h"
+#include "utils/GTUtilsDialog.h"
 #include "api/GTRegionSelector.h"
 #include <U2Algorithm/SmithWatermanSettings.h>
 
 namespace U2 {
-
+using namespace HI;
 class FindRepeatsDialogFiller : public Filler {
 public:
     enum Button {Start, Cancel};
 
-    FindRepeatsDialogFiller(U2OpStatus &_os, const QString & _resultFilesPath, bool _searchInverted = false);
-    
-    virtual void run();
+    FindRepeatsDialogFiller(HI::GUITestOpStatus &os, const QString & _resultFilesPath, bool _searchInverted = false,
+        int minRepeatLength = -1, int repeatsIdentity = -1, int minDistance = -1);
+    FindRepeatsDialogFiller(HI::GUITestOpStatus &os, CustomScenario *scenario);
+
+    virtual void commonScenario();
     Button button;
 
 private:
     QString resultAnnotationFilesPath;
     bool searchInverted;
+    int minRepeatLength;
+    int repeatsIdentity;
+    int minDistance;
 };
 
 } // namespace U2
 
-#endif // _U2_GT_RUNNABLES_FIND_REPEATS_DIALOG_FILLER_H_
\ No newline at end of file
+#endif // _U2_GT_RUNNABLES_FIND_REPEATS_DIALOG_FILLER_H_
